@@ -1,10 +1,11 @@
 import argparse
 
+
 def demo():
-    from starid import Starid
-    starid = Starid()
-    starid.sky()
-    starid.plot(starndx=3)
+    from starid.demo import Demo
+    demo = Demo()
+    demo.plot(starndx=3)
+
 
 if __name__ == '__main__':
     parser = argparse.ArgumentParser('starid')
